#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://code.google.com/p/libproxy/
# source location    : http://libproxy.googlecode.com/files/libproxy-0.4.7.tar.bz2
# last revised       : 5.8.2011
# dep                : 

softname='libproxy'
softversion='0.4.7'
packageversion='72.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://libproxy.googlecode.com/files/$softname-$softversion.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
libproxy: libproxy - a library handling all the details of proxy configuration
libproxy:
libproxy: libproxy is a library that provides automatic proxy configuration
libproxy: management.
libproxy:
libproxy:
libproxy:
libproxy:
libproxy:
libproxy:
libproxy:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
  
mkdir build
cd build
cmake -DCMAKE_INSTALL_PREFIX=/usr \
    -DCMAKE_BUILD_TYPE=None \
    -DWITH_KDE4=OFF \
    -DWITH_PYTHON=ON \
    -DWITH_GNOME=ON \
    -DWITH_PERL=OFF \
    -DWITH_VALA=ON \
    -DWITH_DOTNET=OFF \
    -DWITH_MOZJS=OFF \
    -DWITH_WEBKIT=OFF \
    -DWITH_NETWORKMANAGER=ON \
    -DBUILD_SHARED_LIBS:BOOL=ON \
    -DCMAKE_CXX_FLAGS="${CXXFLAGS}" \
    -DCMAKE_C_FLAGS="${CFLAGS}" \
    ..
make
make install DESTDIR=$dest

# add 'default' files
cd $src
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
   AUTHORS COPYING ChangeLog INSTALL NEWS README\
   $dest/usr/doc/$softname-$softversion
        
# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "e2fsprogs,libICE,libSM,libX11,libXau,libXdmcp,libXext,libXmu,libXt,libxcb" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/l/libproxy/source/build-libproxy.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
